==> SplineDV_0.99.8.tar.gz: SplineDV/inst/doc/SplineDV.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(echo=TRUE)

## ----Installation, eval=FALSE-------------------------------------------------
# if (!requireNamespace("BiocManager", quietly=TRUE))
#     install.packages("BiocManager")
# 
# BiocManager::install("Xenon8778/SplineDV")

## -----------------------------------------------------------------------------
library(scRNAseq)
library(SplineDV)

## ----loadingExampleData, message=FALSE----------------------------------------
sce <- fetchDataset('zilionis-lung-2019','2023-12-20', path="mouse")
sce

## ----SplittingExperimentalConditions------------------------------------------
# Extract Healthy data
healthyCount <- sce[, sce$Tissue == "healthy"]

# Extract Tumor data
tumorCount <- sce[, sce$Tissue == "tumor"]

# Select a specific cell type - Neutrophils
healthyCount <- healthyCount[, which(healthyCount$`Major cell type` == "Neutrophils")]
print(healthyCount)

tumorCount <- tumorCount[, which(tumorCount$`Major cell type` == "Neutrophils")]
print(tumorCount)

## ----runSplineDV--------------------------------------------------------------
dvRes <- splineDV(X = tumorCount, Y = healthyCount)
head(dvRes)

## ----plotDV, out.width="75%", out.height="75%", fig.format='png'--------------
fig <- DVPlot(dvRes, targetgene='Spp1')
fig 

## ----loadHVGExampleData-------------------------------------------------------
# Load data
sce <- fetchDataset('zilionis-lung-2019','2023-12-20', path="mouse")

# Extract Healthy data
healthyCount <- sce[, sce$Tissue == "healthy"]

# Select a specific cell type - Neutrophils
healthyCount <- healthyCount[, which(healthyCount$`Major cell type` == "Neutrophils")]
print(healthyCount)

## ----runSplineHVG, results='hide'---------------------------------------------
HVGRes <- splineHVG(healthyCount, nHVGs = 200)
head(HVGRes)

## ----showHVGList--------------------------------------------------------------
# Extracting HVG Gene list
HVGList <- rownames(HVGRes)[HVGRes$HVG == TRUE]
head(HVGList)

## ----plotHVG, out.width="75%", out.height="75%"-------------------------------
fig <- HVGPlot(HVGRes)
fig

## ----"citation"---------------------------------------------------------------
citation("SplineDV")

## -----------------------------------------------------------------------------
date()
sessionInfo()

==> SplineDV_1.1.1.tar.gz: SplineDV/inst/doc/SplineDV.R <==
## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(echo=TRUE)

## ----Installation, eval=FALSE-------------------------------------------------
# if (!requireNamespace("BiocManager", quietly=TRUE))
#     install.packages("BiocManager")
# 
# BiocManager::install("Xenon8778/SplineDV")

## ----Importlibraries, message=FALSE-------------------------------------------
library(scRNAseq)
library(SplineDV)

## ----LoadingExampleData-------------------------------------------------------
sce <- fetchDataset('zilionis-lung-2019','2023-12-20', path="mouse")
sce

## ----MajorCellTypes-----------------------------------------------------------
table(sce$`Major cell type`,sce$`Tissue`)

## ----SplittingExperimentalConditions------------------------------------------
# Extract Healthy data
healthyCount <- sce[, sce$Tissue == "healthy"]

# Extract Tumor data
tumorCount <- sce[, sce$Tissue == "tumor"]

# Select a specific cell type - Neutrophils
healthyCount <- healthyCount[, which(healthyCount$`Major cell type` == "Neutrophils")]
print(healthyCount)

tumorCount <- tumorCount[, which(tumorCount$`Major cell type` == "Neutrophils")]
print(tumorCount)

## ----runSplineDV--------------------------------------------------------------
dvRes <- splineDV(X = tumorCount, Y = healthyCount)
head(dvRes)

## ----plotDV, out.width="75%", out.height="75%", fig.format='png'--------------
fig <- DVPlot(dvRes, targetgene='Spp1')
fig 

## ----loadHVGExampleData-------------------------------------------------------
# Healthy neutrophils data
print(healthyCount)

## ----runSplineHVG-------------------------------------------------------------
HVGRes <- splineHVG(healthyCount, nHVGs = 200)
head(HVGRes)

## ----showHVGList--------------------------------------------------------------
# Extracting HVG Gene list
HVGList <- rownames(HVGRes)[HVGRes$HVG == TRUE]
head(HVGList)

## ----plotHVG, out.width="75%", out.height="75%"-------------------------------
fig <- HVGPlot(HVGRes)
fig

## ----"citation"---------------------------------------------------------------
citation("SplineDV")

## -----------------------------------------------------------------------------
date()
sessionInfo()
